Fedimg provides a growing suite of unittests that can be run using `python
setup.py test`, or by running the `nosetests` command provided by the `nose`
Python package.

## Setup

Running `python setup.py test` from within your virtualenv will install any
packages required by the test suite, including `nose`, and then run the tests.
